@@ -359,6 +359,11 @@ def distributed_recovery(function_handle,database,options,simulations_list,manag
         filename=queue_result.get()
         source_data=netCDF4.Dataset(filename,'r')
         source_data_hdf5=h5py.File(filename,'r')
+        #print arg
+        #print 'Output:'
+        #print_recursive(output_root)
+        #print 'Source:'
+        #print_recursive(source_data)
         nc_Database.record_to_file(output_root,source_data,source_data_hdf5)
         source_data_hdf5.close()
         source_data.close()
@@ -373,6 +378,13 @@ def distributed_recovery(function_handle,database,options,simulations_list,manag
 
     return output_root
 
+def print_recursive(data):
+    print data
+    for group in data.groups.keys():
+        print group
+        print_recursive(data.groups[group])
+    return
+
 def worker_query(tuple):
     result=tuple[0](*tuple[1:-1])
     sys.stdout.flush()
@@ -442,9 +454,10 @@ def launch_download_and_remote_retrieve(output,data_node_list,queues,retrieval_f
 def progress_report(retrieval_function,output,tuple,queues,queues_size,data_node_list,start_time):
     if retrieval_function=='retrieve_path':
         #print '\t', queues['end'].get()
-        print '\t', tuple
-        elapsed_time = datetime.datetime.now() - start_time
-        print str(elapsed_time)
+        if tuple!=None:
+            print '\t', tuple
+            elapsed_time = datetime.datetime.now() - start_time
+            print str(elapsed_time)
     elif retrieval_function=='retrieve_path_data':
         #netcdf_utils.assign_tree(output,*queues['end'].get())
         netcdf_utils.assign_tree(output,*tuple)
