@@ -10,10 +10,20 @@ import urllib2
 import httplib
 
 def descend_tree(database,search_path,options,list_level=None):
+    list_names=[('experiment','experiment_list'),('var','variable_list')]
+    lists_to_loop=dict()
+    for id in list_names:
+        if id[0] in dir(options) and getattr(options,id[0])!=None:
+            lists_to_loop[id[1]]=options.experiment
+        else:
+            lists_to_loop[id[1]]=database.header[id[1]].keys()
+    for id in lists_to_loop.keys():
+        if not isinstance(lists_to_loop[id],list): lists_to_loop[id]=[lists_to_loop[id]]
+
     #Create the database:
     only_list=[]
-    for experiment in database.header['experiment_list'].keys():
-        for var_name in database.header['variable_list'].keys():
+    for var_name in lists_to_loop['variable_list']:
+        for experiment in lists_to_loop['experiment_list']:
             only_list.append(experiment_variable_search(database.nc_Database,search_path,database.header['file_type_list'],options,
                                         experiment,var_name,database.header['variable_list'][var_name],list_level=list_level))
     return [item for sublist in only_list for item in sublist]
