@@ -188,10 +188,10 @@ def retrieve_path_data(in_dict,pointer_var):
             indices[dim], unsort_indices[dim] = indices_utils.prepare_indices(
                                                             indices_utils.get_indices_from_dim(remote_dim,indices[dim]))
     
-    try:
-        retrieved_data=grab_remote_indices(remote_data.Dataset.variables[var],indices,unsort_indices)
-    except RuntimeError:
-        retrieved_data=grab_remote_indices_pedantic(remote_data.Dataset.variables[var],indices,unsort_indices)
+    #try:
+    retrieved_data=grab_remote_indices(remote_data.Dataset.variables[var],indices,unsort_indices)
+    #except RuntimeError:
+    #    retrieved_data=grab_remote_indices_pedantic(remote_data.Dataset.variables[var],indices,unsort_indices)
 
     remote_data.close()
     return (retrieved_data, sort_table,pointer_var+[var])
@@ -205,9 +205,6 @@ def get_data_node(path,file_type):
         return ''
 
 
-#def add_axis(array,axis_id):
-#    return np.reshape(array,(1,)+array.shape)
-
 def grab_remote_indices(variable,indices,unsort_indices):
     dimensions=variable.dimensions
     return retrieve_slice(variable,indices,unsort_indices,dimensions[0],dimensions[1:],0)
@@ -228,11 +225,43 @@ def retrieve_slice(variable,indices,unsort_indices,dim,dimensions,dim_id,getitem
                                                  indices[dim]),
                               axis=dim_id),unsort_indices[dim],axis=dim_id)
 
+def getitem_pedantic(shape,getitem_tuple):
+    getitem_tuple_fixed=()
+    for item_id, item in enumerate(getitem_tuple):
+        indices_list=range(shape[item_id])[item]
+        if indices_list[-1]+item.step>shape[item_id]:
+            #Must fix the slice:
+            #getitem_tuple_fixed+=(slice(item.start,shape[item_id],item.step),)
+            getitem_tuple_fixed+=(indices_list,)
+        else:
+            getitem_tuple_fixed+=(item,)
+    return getitem_tuple_fixed
+        
 def grab_remote_indices_pedantic(variable,indices,unsort_indices):
     dimensions=variable.dimensions
     return retrieve_slice_pedantic(variable,indices,unsort_indices,dimensions[0],dimensions[1:],0)
 
 def retrieve_slice_pedantic(variable,indices,unsort_indices,dim,dimensions,dim_id,getitem_tuple=tuple()):
+    if len(dimensions)>0:
+        return np.take(np.concatenate(map(lambda x: retrieve_slice_pedantic(variable,
+                                                 indices,
+                                                 unsort_indices,
+                                                 dimensions[0],
+                                                 dimensions[1:],
+                                                 dim_id+1,
+                                                 getitem_tuple=getitem_tuple+(x,)),
+                                                 indices[dim]),
+                              axis=dim_id),unsort_indices[dim],axis=dim_id)
+    else:
+        shape=variable.shape
+        print map(lambda x: getitem_tuple+(x,),indices[dim])
+        print map(lambda x: getitem_pedantic(shape,getitem_tuple+(x,)),indices[dim])
+        return np.take(np.concatenate(map(lambda x: variable.__getitem__(getitem_pedantic(variable.shape,getitem_tuple+(x,))),
+                                                 indices[dim]),
+                              axis=dim_id),unsort_indices[dim],axis=dim_id)
+
+
+def retrieve_slice_pedantic_bak(variable,indices,unsort_indices,dim,dimensions,dim_id,getitem_tuple=tuple()):
     if len(dimensions)>0:
         return np.take(np.concatenate(map(lambda x: 
                                                  remove_zero_if_added(
